.. :changelog:

Release History
---------------

dev
+++

0.3.0 (2018-07-17)
+++++++++++++++++++

**Improvements**

- nbsrc script that converts Jupyter notebooks to R and python scripts
- src plugin for nbconvert
- Initial documentation (readme)
